kwimage.algo.\_nms\_backend.py\_nms module
==========================================

.. automodule:: kwimage.algo._nms_backend.py_nms
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
